@@ -1,4 +1,5 @@
-from typing import Callable, Dict, Optional, Union
+import importlib
+from typing import Callable, List, Optional, Union
 
 from .http_method import HttpMethod
 from .http_request import HttpRequest
@@ -12,26 +13,22 @@ from .serverless.wrapper import create_serverless_function
 class Application:
     def __init__(self, *middleware: Union[Middleware, Callable]):
         self.parent: Optional[Application] = None
-        self.middleware = MiddlewarePipeline()
+        self._middleware = MiddlewarePipeline()
         for item in middleware:
-            self.middleware.append(item)
+            self._middleware.append(item)
 
         self.namespace = ["/"]
-        self.routes: Dict[HttpMethod, Router] = {key: Router() for key in HttpMethod}
+        self.router = Router()
+        self._loaded_modules: List[str] = []
+        self._cached_middleware: Optional[MiddlewarePipeline] = None
 
     def _append_route(
-        self,
-        method: HttpMethod,
-        route: Route,
-        handler: Callable[[HttpRequest], HttpResponse],
+        self, method: HttpMethod, route: Route, handler: Callable[[HttpRequest], HttpResponse],
     ):
         if self.parent:
             self.parent._append_route(method, route, handler)
 
-        if method not in self.routes:
-            self.routes[method] = Router()
-
-        self.routes[method].append(route, handler)
+        self.router.append(route, handler, method)
 
     def _create_route(self, route: str) -> Route:
         base_uri = "".join(self.namespace[1:])
@@ -41,7 +38,7 @@ class Application:
         def _get(handler: Callable) -> Callable:
             r = self._create_route(route)
             self._append_route(HttpMethod.GET, r, handler)
-            return create_serverless_function(handler, r, self.middleware)
+            return create_serverless_function(handler, r, self._middleware)
 
         return _get
 
@@ -49,7 +46,7 @@ class Application:
         def _post(handler: Callable) -> Callable:
             r = self._create_route(route)
             self._append_route(HttpMethod.POST, r, handler)
-            return create_serverless_function(handler, r, self.middleware)
+            return create_serverless_function(handler, r, self._middleware)
 
         return _post
 
@@ -57,7 +54,7 @@ class Application:
         def _put(handler: Callable) -> Callable:
             r = self._create_route(route)
             self._append_route(HttpMethod.PUT, r, handler)
-            return create_serverless_function(handler, r, self.middleware)
+            return create_serverless_function(handler, r, self._middleware)
 
         return _put
 
@@ -65,7 +62,7 @@ class Application:
         def _patch(handler: Callable) -> Callable:
             r = self._create_route(route)
             self._append_route(HttpMethod.PATCH, r, handler)
-            return create_serverless_function(handler, r, self.middleware)
+            return create_serverless_function(handler, r, self._middleware)
 
         return _patch
 
@@ -73,7 +70,7 @@ class Application:
         def _delete(handler: Callable) -> Callable:
             r = self._create_route(route)
             self._append_route(HttpMethod.DELETE, r, handler)
-            return create_serverless_function(handler, r, self.middleware)
+            return create_serverless_function(handler, r, self._middleware)
 
         return _delete
 
@@ -81,7 +78,7 @@ class Application:
         def _head(handler: Callable) -> Callable:
             r = self._create_route(route)
             self._append_route(HttpMethod.HEAD, r, handler)
-            return create_serverless_function(handler, r, self.middleware)
+            return create_serverless_function(handler, r, self._middleware)
 
         return _head
 
@@ -89,7 +86,7 @@ class Application:
         def _options(handler: Callable) -> Callable:
             r = self._create_route(route)
             self._append_route(HttpMethod.OPTIONS, r, handler)
-            return create_serverless_function(handler, r, self.middleware)
+            return create_serverless_function(handler, r, self._middleware)
 
         return _options
 
@@ -104,7 +101,7 @@ class Application:
             self._append_route(HttpMethod.HEAD, r, handler)
             self._append_route(HttpMethod.OPTIONS, r, handler)
 
-            return create_serverless_function(handler, r, self.middleware)
+            return create_serverless_function(handler, r, self._middleware)
 
         return _any
 
@@ -114,9 +111,10 @@ class Application:
 
     def __enter__(self) -> "Application":
         child_app = Application()
-        child_app.middleware = self.middleware
+        child_app._middleware = self._middleware
         child_app.namespace = self.namespace
         child_app.parent = self
+        child_app._loaded_modules = self._loaded_modules
 
         return child_app
 
@@ -125,13 +123,23 @@ class Application:
         return self
 
     def __call__(self, request: HttpRequest) -> HttpResponse:
-        routing = RouterMiddleware()
-        routing.routes = self.routes
+        return self._application_middleware(request)
 
-        middleware = MiddlewarePipeline(self.middleware.queue)
-        middleware.append(routing)
+    def use(self, module: str) -> None:
+        if module in self._loaded_modules:
+            return
 
-        return middleware(request)
+        importlib.import_module(module)
+        self._loaded_modules.append(module)
+
+    @property
+    def _application_middleware(self) -> MiddlewarePipeline:
+        if self._cached_middleware is None:
+            middleware = MiddlewarePipeline(self._middleware.queue)
+            middleware.append(RouterMiddleware(self.router))
+            self._cached_middleware = middleware
+
+        return self._cached_middleware
 
 
 __all__ = ["Application"]
