@@ -1,9 +1,4 @@
-from typing import Generator
-from typing import KeysView
-from typing import Optional
-from typing import Sequence
-from typing import Union
-from typing import ValuesView
+from typing import Generator, KeysView, Optional, Sequence, Union, ValuesView
 
 
 def _normalize_header_name(name: str) -> str:
