@@ -1,7 +1,6 @@
-from typing import Callable, Dict, Union
+from typing import Callable, Union
 
 from .http_error import HttpError
-from .http_method import HttpMethod
 from .http_request import HttpRequest
 from .http_response import HttpResponse
 from .middleware import Middleware, MiddlewareHandler
@@ -10,13 +9,13 @@ from .serverless.serverless import ServerlessFunction
 
 
 class RouterMiddleware(Middleware):
-    def __init__(self):
-        self.routes: Dict[HttpMethod, Router] = {key: Router() for key in HttpMethod}
+    def __init__(self, router: Router):
+        self.router = router
 
     def handle(self, request: HttpRequest, next: MiddlewareHandler) -> HttpResponse:
         try:
-            route, controller = self.routes[request.method].match(
-                request.path
+            route, controller = self.router.match(
+                request.path, request.method
             )  # type: Route, Union[Callable, ServerlessFunction]
 
             request.path_parameters = route.parameters
