@@ -10,9 +10,7 @@ from .serverless import IS_AWS_ENVIRONMENT, ServerlessFunction
 
 
 def create_serverless_function(
-    func: Callable[[HttpRequest], HttpResponse],
-    route: Route,
-    middleware_pipeline: MiddlewarePipeline,
+    func: Callable[[HttpRequest], HttpResponse], route: Route, middleware_pipeline: MiddlewarePipeline,
 ) -> Callable:
 
     if IS_AWS_ENVIRONMENT:
