@@ -48,8 +48,7 @@ def create_wsgi_handler(
                 response = HttpResponse("Internal Server Error", 500)
 
         start(
-            str(int(response.status_code)),
-            [(key, value) for key, value in response.headers.items()],
+            str(int(response.status_code)), [(key, value) for key, value in response.headers.items()],
         )
 
         response.body.seek(0)
@@ -58,9 +57,7 @@ def create_wsgi_handler(
     return _handler
 
 
-def serve(
-    application: Application, host: str = "127.0.0.1", port=80, debug: bool = False
-) -> None:
+def serve(application: Application, host: str = "127.0.0.1", port=80, debug: bool = False) -> None:
     import bjoern
 
     wsgi_handler = create_wsgi_handler(application, debug=debug)
